@@ -1,6 +1,7 @@
 import json
 from typing import Any, Callable, Dict, List, Mapping, Optional, Union
 
+import requests
 import typer
 import yaml
 from globus_sdk import GlobusAPIError, GlobusHTTPResponse
@@ -37,11 +38,18 @@ output_format_option: OutputFormat = typer.Option(
 
 def get_http_details(result: Union[GlobusHTTPResponse, GlobusAPIError]) -> str:
     if isinstance(result, GlobusHTTPResponse):
-        base_request = result._data.request
-        reponse_status_code = result._data.status_code
-    elif isinstance(result, GlobusAPIError):
+        if isinstance(result._response, requests.Response):
+            base_request = result._response.request
+        elif result._wrapped and isinstance(
+            result._wrapped._response, requests.Response
+        ):
+            base_request = result._wrapped._response.request
+        else:
+            return "HTTP details are unavailable"
+        response_status_code = result.http_status
+    else:  # isinstance(result, GlobusAPIError)
         base_request = result._underlying_response.request
-        reponse_status_code = result._underlying_response.status_code
+        response_status_code = result._underlying_response.status_code
 
     formatted_headers = "\n".join(
         f"  {k}: {v}" for k, v in base_request.headers.items()
@@ -49,7 +57,7 @@ def get_http_details(result: Union[GlobusHTTPResponse, GlobusAPIError]) -> str:
     http_details = (
         f"Request: {base_request.method} {base_request.url}\n"
         f"Headers:\n{formatted_headers}\n"
-        f"Response: {reponse_status_code}"
+        f"Response: {response_status_code}"
     )
     return http_details
 
@@ -67,7 +75,7 @@ def process_input(input_arg: Optional[str]) -> Optional[Mapping[str, Any]]:
         try:
             input_dict = yaml.safe_load(input_arg)
         except yaml.YAMLError:
-            raise typer.BadParameter(f"Unable to load input as JSON or YAML")
+            raise typer.BadParameter("Unable to load input as JSON or YAML")
 
     return input_dict
 
