@@ -16,7 +16,7 @@ from typing import (
     TypeVar,
     Union,
 )
-from urllib.parse import quote, urljoin
+from urllib.parse import quote, urljoin, urlparse
 
 from globus_sdk import (
     AccessTokenAuthorizer,
@@ -221,6 +221,8 @@ class FlowsClient(BaseClient):
         get_authorizer_callback: AuthorizerCallbackType,
         **kwargs,
     ) -> None:
+        if "base_url" not in kwargs:
+            kwargs["base_url"] = _get_flows_base_url_for_environment()
         super().__init__(**kwargs)
         self.client_id = client_id
         self.get_authorizer_callback = get_authorizer_callback
@@ -1241,6 +1243,7 @@ class FlowsClient(BaseClient):
         """
         if base_url is None:
             base_url = _get_flows_base_url_for_environment()
+        verify_ssl = urlparse(base_url).hostname not in {"localhost", "127.0.0.1"}
         return cls(
             client_id,
             authorizer_callback,
@@ -1249,5 +1252,6 @@ class FlowsClient(BaseClient):
             authorizer=authorizer,
             transport_params={
                 "http_timeout": http_timeout,
+                "verify_ssl": verify_ssl,
             },
         )
